==> editData_0.1.0.tar.gz: editData/inst/doc/editData.R <==
## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE,comment =NA,fig.align='center',out.width="70%")

## ----eval=FALSE----------------------------------------------------------
#  install.packages("editData")

## ----eval=FALSE----------------------------------------------------------
#  #install.packages("devtools")
#  devtools::install_github("cardiomoon/editData")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/1.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/2.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/3.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/4.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/5.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/6.png")

## ----eval=FALSE----------------------------------------------------------
#  require(editData)
#  result <- editData(mtcars)

==> editData_0.1.2.tar.gz: editData/inst/doc/editData.R <==
## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE,comment =NA,fig.align='center',out.width="70%")

## ----eval=FALSE----------------------------------------------------------
#  install.packages("editData")

## ----eval=FALSE----------------------------------------------------------
#  #install.packages("devtools")
#  devtools::install_github("cardiomoon/editData")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/1.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/2.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/3.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/4.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/5.png")

## ----echo=FALSE----------------------------------------------------------
knitr::include_graphics("https://raw.githubusercontent.com/cardiomoon/editData/master/man/figures/6.png")

## ----eval=FALSE----------------------------------------------------------
#  require(editData)
#  result <- editData(mtcars)

## ----eval=FALSE----------------------------------------------------------
#  shiny::runApp(system.file('example',package='editData'))
#  shiny::runApp(system.file('multipleData',package='editData'))
#  shiny::runApp(system.file('multipleFiles',package='editData'))
